# YAPyBrot

Yet Another Python Mandelbrot

## Quickstart

```
pip install yapybrot
```
See [./examples](./examples) for usage.

## Installation from Source

Prerequisites:

* Python >= 3.8
* Anaconda / Miniconda
* CMake

```
conda install -c conda-forge --file requirements.txt
pip install -e .
```
